# lambdata-dustinstringer
A collection of datascience utility functions.

## Installation:
    pip install lambdata-dustinstringer
  
## Modules:
- dustydata.wild_west <-- module for data wrangling and feature engineering

## Classes:
- dustydata.wild_west.johnWayne(dataframe, check_null=boolean, check_data_types=boolean)

## Attributes/Methods/Functions:
- dustydata.wild_west.johnWayne.cardinality_cutter(threshold=int)
- dustydata.wild_west.johnWayne.tri_split(val_size=float, test_size=float)
    
